==> davmail_4.8.3.2554.orig.tar.gz: davmail-4.8.3-2554/src/test/davmail/ui/TestNotificationDialog.java <==
/*
 * DavMail POP/IMAP/SMTP/CalDav/LDAP Exchange Gateway
 * Copyright (C) 2010  Mickael Guessant
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package davmail.ui;

import junit.framework.TestCase;

import javax.swing.*;
import java.io.IOException;

/**
 * Test Notification Frame
 */
public class TestNotificationDialog extends TestCase {
    public void testCreateNotificationFrame() throws IOException, ClassNotFoundException, UnsupportedLookAndFeelException, IllegalAccessException, InstantiationException {
        UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
        NotificationDialog notificationDialog = new NotificationDialog("to", "cc", "subject", "description");
        notificationDialog.setVisible(true);
        System.out.println(notificationDialog.getSendNotification());
    }
}

==> davmail_5.4.0.3135.orig.tar.gz: davmail-5.4.0-3135/src/test/davmail/ui/TestNotificationDialog.java <==
/*
 * DavMail POP/IMAP/SMTP/CalDav/LDAP Exchange Gateway
 * Copyright (C) 2010  Mickael Guessant
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package davmail.ui;

import junit.framework.TestCase;

import javax.swing.*;
import java.io.IOException;

/**
 * Test Notification Frame
 */
public class TestNotificationDialog extends TestCase {
    public void testCreateNotificationFrame() throws IOException, ClassNotFoundException, UnsupportedLookAndFeelException, IllegalAccessException, InstantiationException {
        UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
        NotificationDialog notificationDialog = new NotificationDialog("to", "cc", "subject", "description");
        notificationDialog.setVisible(true);
        System.out.println(notificationDialog.getSendNotification());
    }

    public void testCreateNotificationFromEWSFrame() throws IOException, ClassNotFoundException, UnsupportedLookAndFeelException, IllegalAccessException, InstantiationException {
        UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
        NotificationDialog notificationDialog = new NotificationDialog("subject", "description");
        notificationDialog.setVisible(true);
        System.out.println(notificationDialog.getSendNotification());
    }
}
